@@ -2,12 +2,10 @@ use alloc::vec;
 use core::convert::TryInto;
 
 use crate::ross_convert_packet::{RossConvertPacket, RossConvertPacketError};
+use crate::ross_event::ross_event_code::*;
 use crate::ross_event::ross_event_packet::RossEventPacketError;
 use crate::ross_packet::RossPacket;
 
-pub const ROSS_PROGRAMMER_HELLO_EVENT_CODE: u16 = 0x0001;
-pub const ROSS_PROGRAMMER_START_UPLOAD_EVENT_CODE: u16 = 0x0002;
-
 #[derive(Debug, PartialEq)]
 pub struct RossProgrammerHelloEvent {
     pub programmer_address: u16,
@@ -15,7 +13,7 @@ pub struct RossProgrammerHelloEvent {
 }
 
 impl RossConvertPacket<RossProgrammerHelloEvent> for RossProgrammerHelloEvent {
-    fn try_from_packet(packet: RossPacket) -> Result<Self, RossConvertPacketError> {
+    fn try_from_packet(packet: &RossPacket) -> Result<Self, RossConvertPacketError> {
         if packet.data.len() != 6 {
             return Err(RossConvertPacketError::WrongSize);
         }
@@ -42,7 +40,7 @@ impl RossConvertPacket<RossProgrammerHelloEvent> for RossProgrammerHelloEvent {
     }
 
     fn to_packet(&self) -> RossPacket {
-        let mut data = vec!();
+        let mut data = vec![];
 
         for byte in u16::to_be_bytes(ROSS_PROGRAMMER_HELLO_EVENT_CODE).iter() {
             data.push(*byte);
@@ -69,7 +67,7 @@ pub struct RossProgrammerStartUploadEvent {
 }
 
 impl RossConvertPacket<RossProgrammerStartUploadEvent> for RossProgrammerStartUploadEvent {
-    fn try_from_packet(packet: RossPacket) -> Result<Self, RossConvertPacketError> {
+    fn try_from_packet(packet: &RossPacket) -> Result<Self, RossConvertPacketError> {
         if packet.data.len() != 12 {
             return Err(RossConvertPacketError::WrongSize);
         }
@@ -100,7 +98,7 @@ impl RossConvertPacket<RossProgrammerStartUploadEvent> for RossProgrammerStartUp
     }
 
     fn to_packet(&self) -> RossPacket {
-        let mut data = vec!();
+        let mut data = vec![];
 
         for byte in u16::to_be_bytes(ROSS_PROGRAMMER_START_UPLOAD_EVENT_CODE).iter() {
             data.push(*byte);
