@@ -3,6 +3,7 @@ use alloc::vec::Vec;
 
 use crate::ross_convert_packet::RossConvertPacket;
 use crate::ross_event::ross_configurator_event::*;
+use crate::ross_event::ross_event_code::*;
 use crate::ross_packet::RossPacket;
 
 const EVENT_PACKET: RossPacket = RossPacket {
@@ -15,11 +16,11 @@ const EVENT_PACKET: RossPacket = RossPacket {
 fn try_from_packet_configurator_hello_event_test() {
     let mut packet = EVENT_PACKET;
     packet.data = vec![
-        0x00, // event code
-        0x05, // event code
+        ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 8) & 0xff) as u8, // event code
+        ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 0) & 0xff) as u8, // event code
     ];
 
-    RossConfiguratorHelloEvent::try_from_packet(packet).unwrap();
+    RossConfiguratorHelloEvent::try_from_packet(&packet).unwrap();
 }
 
 #[test]
@@ -28,8 +29,8 @@ fn to_packet_configurator_hello_event_test() {
 
     let mut packet = EVENT_PACKET;
     packet.data = vec![
-        0x00, // event code
-        0x05, // event code
+        ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 8) & 0xff) as u8, // event code
+        ((ROSS_CONFIGURATOR_HELLO_EVENT_CODE >> 0) & 0xff) as u8, // event code
     ];
 
     assert_eq!(configurator_hello_event.to_packet(), packet);
